
"""
pylings.__init__

This module initializes the pylings package and sets the version.

Attributes:
    __version__ (str): The current version of the pylings package.
"""
__version__ = "1.3.0"
# End-of-file (EOF)
